__shared__ 배열 선언하기
블록마다 빠른 임시 메모리를 사용합니다.
__shared__ 배열 선언하기은(는) CoddyKit의 무료 CUDA Academy 강의입니다. 이것은 4개 중 1번째 강의입니다. 아래에서 전체 강의를 무료로 읽을 수 있으며, 내장 코드 에디터와 24/7 AI 튜터와 함께 브라우저에서 직접 실습할 수 있습니다. 이 강의는 CUDA Academy 학습 경로의 일부이며, 진행 상황이 웹과 CoddyKit 앱에 동기화됩니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.
이 강의의 일부는 아직 번역되지 않았으며 영어로 표시됩니다.
A Scratchpad Per Block
Every block gets a tiny, fast pool of on-chip memory called shared memory. Think of it as a scratchpad the whole block can write to and read from together.
Why It Is So Fast
Shared memory sits right on the streaming multiprocessor, so it is roughly 100x faster than global memory. Use it to avoid hammering slow off-chip DRAM. 🚀
The __shared__ Keyword
You declare it with the __shared__ qualifier inside a kernel. This one array is then shared by every thread in the block.
__global__ void kern() {
__shared__ float tile[256];
}Fixed Size at Compile Time
When you give a size in brackets, that is static shared memory. The compiler must know the size, so it has to be a constant, not a runtime value.
__shared__ int counts[128];One Copy, Not One Per Thread
This is the key idea: a __shared__ array is created once per block, not once per thread. All threads see the exact same array.
Threads Cooperate Through It
Because every thread sees the same data, shared memory lets threads cooperate. One thread can stash a value and a neighbor can pick it up.
Block Scope, Not Beyond
Its lifetime matches the block. The array is born when the block starts and gone when it ends, so it has block scope only. 🧱
Each Thread Owns a Slot
A common pattern is one slot per thread, indexed by threadIdx.x. Each thread loads its element into shared memory in parallel.
__shared__ float s[256];
s[threadIdx.x] = input[i];A Tiny but Precious Resource
Shared memory is small, often just 48 to 100 KB per SM. Asking for too much per block reduces how many blocks can run at once.
The Classic Use: Staging Tiles
The most common job is staging a tile of global data so the block can reuse it many times without going back to slow DRAM.
Not Visible to Other Blocks
Remember the boundary: shared memory is private to its block. Two different blocks each get their own separate copy and cannot peek at each other.
Quick Check
Let us check how shared memory is scoped.
Recap
You learned that __shared__ gives each block a fast on-chip scratchpad, created once per block and ideal for staging reusable data. Next: keeping threads in step. 🎯
자주 묻는 질문
“__shared__ 배열 선언하기” 강의는 무료인가요?
네 — “__shared__ 배열 선언하기” 전체 내용을 이 웹사이트에서 무료로 읽을 수 있습니다. 인터랙티브하게 실습하려면(내장 코드 에디터와 24/7 AI 튜터), CoddyKit PRO로 업그레이드하면 CUDA Academy 강의 전체를 잠금 해제할 수 있습니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.
“__shared__ 배열 선언하기”에서 뭘 배우나요?
블록마다 빠른 임시 메모리를 사용합니다. 브라우저에서 직접 실행하는 실습 코드로 CUDA Academy을(를) 배우며, 24/7 AI 튜터가 강의를 진행하면서 질문에 답변해줍니다.
CUDA Academy을(를) 시작하는 데 경험이 필요한가요?
사전 경험은 필요하지 않습니다. CoddyKit의 CUDA Academy은(는) 초급자부터 고급 학습자까지를 위해 구성되어 있으므로, 여기서 시작하거나 처음부터 시작할 수 있으며 자신의 속도대로 진행할 수 있습니다. 이것은 4개 중 1번째 강의입니다.
“__shared__ 배열 선언하기” 강의는 얼마나 걸리나요?
대부분의 CoddyKit 강의는 약 5~10분이 소요됩니다. 각 강의는 간결하고 인터랙티브하여 꾸준한 진행이 가능하며, 웹과 앱에서 중단한 부분부터 바로 시작할 수 있습니다.
이 CUDA Academy 강의에서 코드를 작성하고 실행할 수 있나요?
네. 모든 CUDA Academy 강의에는 내장 코드 에디터가 포함되어 있으므로, 브라우저에서 바로 실제 코드를 작성하고 실행한 후 즉시 AI 피드백을 받을 수 있습니다 — 로컬 설정이 필요 없습니다.
이 강의의 모든 강의
- __shared__ 배열 선언하기
- __syncthreads로 동기화하기
- 뱅크 충돌 방지하기
- 동적 공유 메모리